# safe_radix32

## 0.4.0
- Utilities to encode/decode arbitrary bytes to/from safe-radix32 (pure python only)

## 0.3.2
- Fixed fixed-width encode on Windows

## 0.3.1
- Fixed cython build on Windows

## 0.3.0
- Improved TypeError consistency between implementations
- Fixed default imports of the cython build

## 0.2.0
- Added fixed-width version of encode
- Minor improvements

## 0.1.1
- Fixed a performance issue in the cython impl

## 0.1.0
- Initial release
